# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .batch_progress_response_status import BatchProgressResponseStatus


class BatchProgressResponse(UniversalBaseModel):
    version: str
    batch_id: str = pydantic.Field()
    """
    The batch identifier
    """

    progress: float = pydantic.Field()
    """
    Fraction of tasks completed (0.0 to 1.0). Value of 1.0 means all tasks have finished (success or failure).
    """

    tasks_count: int = pydantic.Field()
    """
    Total number of tasks in the batch
    """

    tasks_completed: int = pydantic.Field()
    """
    Number of tasks that completed successfully
    """

    tasks_failed: int = pydantic.Field()
    """
    Number of tasks that failed
    """

    status: BatchProgressResponseStatus = pydantic.Field()
    """
    `processing` while tasks are running; `completed` when all tasks have finished (regardless of individual success/failure)
    """

    results_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to fetch per-task results. Present only when `status` is `completed`.
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message when all tasks in the batch failed. Null otherwise.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .account_object import AccountObject
    from .approver_object import ApproverObject
    from .approver_object_approver import ApproverObjectApprover
    from .approver_object_policy import ApproverObjectPolicy
    from .batch_progress_response import BatchProgressResponse
    from .batch_progress_response_status import BatchProgressResponseStatus
    from .batch_results_response import BatchResultsResponse
    from .batch_results_response_results_item import BatchResultsResponseResultsItem
    from .bulk_invoice_failure import BulkInvoiceFailure
    from .bulk_invoice_operation_response import BulkInvoiceOperationResponse
    from .bulk_invoice_operation_response_failed_item import BulkInvoiceOperationResponseFailedItem
    from .bulk_invoice_unexport_operation_response import BulkInvoiceUnexportOperationResponse
    from .bulk_invoice_unexport_operation_response_failed_item import BulkInvoiceUnexportOperationResponseFailedItem
    from .bulk_invoice_unexport_operation_response_skipped_item import BulkInvoiceUnexportOperationResponseSkippedItem
    from .bulk_upsert_async_response import BulkUpsertAsyncResponse
    from .bulk_upsert_async_response_summary import BulkUpsertAsyncResponseSummary
    from .catalog_allowance_bulk_item import CatalogAllowanceBulkItem
    from .catalog_allowance_bulk_item_allowance_type import CatalogAllowanceBulkItemAllowanceType
    from .catalog_allowance_list_response import CatalogAllowanceListResponse
    from .catalog_allowance_list_response_results_item import CatalogAllowanceListResponseResultsItem
    from .catalog_allowance_list_response_results_item_allowance_type import (
        CatalogAllowanceListResponseResultsItemAllowanceType,
    )
    from .catalog_allowance_list_response_results_item_target_type import (
        CatalogAllowanceListResponseResultsItemTargetType,
    )
    from .catalog_allowance_nested_create_request import CatalogAllowanceNestedCreateRequest
    from .catalog_allowance_nested_create_request_allowance_type import CatalogAllowanceNestedCreateRequestAllowanceType
    from .catalog_allowance_nested_object import CatalogAllowanceNestedObject
    from .catalog_allowance_nested_object_allowance_type import CatalogAllowanceNestedObjectAllowanceType
    from .catalog_allowance_nested_object_target_type import CatalogAllowanceNestedObjectTargetType
    from .catalog_allowance_object import CatalogAllowanceObject
    from .catalog_allowance_object_allowance_type import CatalogAllowanceObjectAllowanceType
    from .catalog_allowance_object_target_type import CatalogAllowanceObjectTargetType
    from .catalog_bulk_error_item import CatalogBulkErrorItem
    from .catalog_bulk_response import CatalogBulkResponse
    from .catalog_bulk_response_errors_item import CatalogBulkResponseErrorsItem
    from .catalog_bulk_response_skipped_item import CatalogBulkResponseSkippedItem
    from .catalog_bulk_skipped_item import CatalogBulkSkippedItem
    from .catalog_entry_basic_object import CatalogEntryBasicObject
    from .catalog_entry_bulk_item import CatalogEntryBulkItem
    from .catalog_entry_bulk_item_allowances_item import CatalogEntryBulkItemAllowancesItem
    from .catalog_entry_bulk_item_allowances_item_allowance_type import CatalogEntryBulkItemAllowancesItemAllowanceType
    from .catalog_entry_bulk_item_prices_item import CatalogEntryBulkItemPricesItem
    from .catalog_entry_bulk_item_prices_item_price_type import CatalogEntryBulkItemPricesItemPriceType
    from .catalog_entry_create_request import CatalogEntryCreateRequest
    from .catalog_entry_create_request_allowances_item import CatalogEntryCreateRequestAllowancesItem
    from .catalog_entry_create_request_allowances_item_allowance_type import (
        CatalogEntryCreateRequestAllowancesItemAllowanceType,
    )
    from .catalog_entry_create_request_prices_item import CatalogEntryCreateRequestPricesItem
    from .catalog_entry_create_request_prices_item_price_type import CatalogEntryCreateRequestPricesItemPriceType
    from .catalog_entry_list_response import CatalogEntryListResponse
    from .catalog_entry_list_response_results_item import CatalogEntryListResponseResultsItem
    from .catalog_entry_object import CatalogEntryObject
    from .catalog_entry_object_allowances_item import CatalogEntryObjectAllowancesItem
    from .catalog_entry_object_allowances_item_allowance_type import CatalogEntryObjectAllowancesItemAllowanceType
    from .catalog_entry_object_allowances_item_target_type import CatalogEntryObjectAllowancesItemTargetType
    from .catalog_entry_object_prices_item import CatalogEntryObjectPricesItem
    from .catalog_entry_object_prices_item_price_type_display import CatalogEntryObjectPricesItemPriceTypeDisplay
    from .catalog_error_response import CatalogErrorResponse
    from .catalog_price_create_request import CatalogPriceCreateRequest
    from .catalog_price_create_request_price_type import CatalogPriceCreateRequestPriceType
    from .catalog_price_item import CatalogPriceItem
    from .catalog_price_item_price_type_display import CatalogPriceItemPriceTypeDisplay
    from .company_object import CompanyObject
    from .error_response import ErrorResponse
    from .instant_capture_file_object import InstantCaptureFileObject
    from .invoice_creation_response import InvoiceCreationResponse
    from .invoice_creation_response_batch import InvoiceCreationResponseBatch
    from .invoice_creation_response_batch_status import InvoiceCreationResponseBatchStatus
    from .invoice_creation_response_container import InvoiceCreationResponseContainer
    from .invoice_creation_response_invoice import InvoiceCreationResponseInvoice
    from .invoice_creation_response_invoice_status import InvoiceCreationResponseInvoiceStatus
    from .invoice_creation_response_processing import InvoiceCreationResponseProcessing
    from .invoice_creation_response_processing_status import InvoiceCreationResponseProcessingStatus
    from .invoice_creation_response_upload import InvoiceCreationResponseUpload
    from .invoice_creation_response_upload_upload_method import InvoiceCreationResponseUploadUploadMethod
    from .invoice_detail_object import InvoiceDetailObject
    from .invoice_detail_object_gl_splits_item import InvoiceDetailObjectGlSplitsItem
    from .invoice_detail_object_history_item import InvoiceDetailObjectHistoryItem
    from .invoice_detail_object_history_item_user import InvoiceDetailObjectHistoryItemUser
    from .invoice_detail_object_images_item import InvoiceDetailObjectImagesItem
    from .invoice_detail_object_items_processing_result import InvoiceDetailObjectItemsProcessingResult
    from .invoice_detail_object_items_processing_result_status import InvoiceDetailObjectItemsProcessingResultStatus
    from .invoice_detail_object_payment_info import InvoiceDetailObjectPaymentInfo
    from .invoice_detail_object_payment_status import InvoiceDetailObjectPaymentStatus
    from .invoice_detail_object_type import InvoiceDetailObjectType
    from .invoice_item_variance_list_response import InvoiceItemVarianceListResponse
    from .invoice_item_variance_list_response_results_item import InvoiceItemVarianceListResponseResultsItem
    from .invoice_needs_attention_object import InvoiceNeedsAttentionObject
    from .invoice_needs_attention_object_on_hold import InvoiceNeedsAttentionObjectOnHold
    from .invoice_needs_attention_object_payment_status import InvoiceNeedsAttentionObjectPaymentStatus
    from .invoice_needs_attention_object_type import InvoiceNeedsAttentionObjectType
    from .invoice_object import InvoiceObject
    from .invoice_object_images_item import InvoiceObjectImagesItem
    from .invoice_object_on_hold import InvoiceObjectOnHold
    from .invoice_object_payment_status import InvoiceObjectPaymentStatus
    from .invoice_object_type import InvoiceObjectType
    from .line_item_object import LineItemObject
    from .location_object import LocationObject
    from .oauth_scope import OauthScope
    from .purchase_order_create_response import PurchaseOrderCreateResponse
    from .purchase_order_create_response_items_item import PurchaseOrderCreateResponseItemsItem
    from .purchase_order_create_response_status import PurchaseOrderCreateResponseStatus
    from .purchase_order_detail import PurchaseOrderDetail
    from .purchase_order_detail_purchase_order import PurchaseOrderDetailPurchaseOrder
    from .purchase_order_detail_purchase_order_items_item import PurchaseOrderDetailPurchaseOrderItemsItem
    from .purchase_order_detail_purchase_order_status import PurchaseOrderDetailPurchaseOrderStatus
    from .purchase_order_summary import PurchaseOrderSummary
    from .purchase_order_summary_status import PurchaseOrderSummaryStatus
    from .purchase_order_update_response import PurchaseOrderUpdateResponse
    from .purchase_order_update_response_status import PurchaseOrderUpdateResponseStatus
    from .receipt_bulk_upsert_async_response import ReceiptBulkUpsertAsyncResponse
    from .receipt_bulk_upsert_async_response_summary import ReceiptBulkUpsertAsyncResponseSummary
    from .receipt_create_response import ReceiptCreateResponse
    from .receipt_create_response_status import ReceiptCreateResponseStatus
    from .receipt_detail import ReceiptDetail
    from .receipt_detail_receipt import ReceiptDetailReceipt
    from .receipt_detail_receipt_items_item import ReceiptDetailReceiptItemsItem
    from .receipt_detail_receipt_status import ReceiptDetailReceiptStatus
    from .receipt_item import ReceiptItem
    from .receipt_summary import ReceiptSummary
    from .receipt_summary_status import ReceiptSummaryStatus
    from .receipt_update_response import ReceiptUpdateResponse
    from .receipt_update_response_status import ReceiptUpdateResponseStatus
    from .variance_list_response import VarianceListResponse
    from .variance_list_response_results_item import VarianceListResponseResultsItem
    from .variance_list_response_results_item_last_invoice_item import VarianceListResponseResultsItemLastInvoiceItem
    from .variance_object import VarianceObject
    from .variance_object_invoice_items import VarianceObjectInvoiceItems
    from .variance_object_invoice_items_data_item import VarianceObjectInvoiceItemsDataItem
    from .variance_object_last_invoice_item import VarianceObjectLastInvoiceItem
_dynamic_imports: typing.Dict[str, str] = {
    "AccountObject": ".account_object",
    "ApproverObject": ".approver_object",
    "ApproverObjectApprover": ".approver_object_approver",
    "ApproverObjectPolicy": ".approver_object_policy",
    "BatchProgressResponse": ".batch_progress_response",
    "BatchProgressResponseStatus": ".batch_progress_response_status",
    "BatchResultsResponse": ".batch_results_response",
    "BatchResultsResponseResultsItem": ".batch_results_response_results_item",
    "BulkInvoiceFailure": ".bulk_invoice_failure",
    "BulkInvoiceOperationResponse": ".bulk_invoice_operation_response",
    "BulkInvoiceOperationResponseFailedItem": ".bulk_invoice_operation_response_failed_item",
    "BulkInvoiceUnexportOperationResponse": ".bulk_invoice_unexport_operation_response",
    "BulkInvoiceUnexportOperationResponseFailedItem": ".bulk_invoice_unexport_operation_response_failed_item",
    "BulkInvoiceUnexportOperationResponseSkippedItem": ".bulk_invoice_unexport_operation_response_skipped_item",
    "BulkUpsertAsyncResponse": ".bulk_upsert_async_response",
    "BulkUpsertAsyncResponseSummary": ".bulk_upsert_async_response_summary",
    "CatalogAllowanceBulkItem": ".catalog_allowance_bulk_item",
    "CatalogAllowanceBulkItemAllowanceType": ".catalog_allowance_bulk_item_allowance_type",
    "CatalogAllowanceListResponse": ".catalog_allowance_list_response",
    "CatalogAllowanceListResponseResultsItem": ".catalog_allowance_list_response_results_item",
    "CatalogAllowanceListResponseResultsItemAllowanceType": ".catalog_allowance_list_response_results_item_allowance_type",
    "CatalogAllowanceListResponseResultsItemTargetType": ".catalog_allowance_list_response_results_item_target_type",
    "CatalogAllowanceNestedCreateRequest": ".catalog_allowance_nested_create_request",
    "CatalogAllowanceNestedCreateRequestAllowanceType": ".catalog_allowance_nested_create_request_allowance_type",
    "CatalogAllowanceNestedObject": ".catalog_allowance_nested_object",
    "CatalogAllowanceNestedObjectAllowanceType": ".catalog_allowance_nested_object_allowance_type",
    "CatalogAllowanceNestedObjectTargetType": ".catalog_allowance_nested_object_target_type",
    "CatalogAllowanceObject": ".catalog_allowance_object",
    "CatalogAllowanceObjectAllowanceType": ".catalog_allowance_object_allowance_type",
    "CatalogAllowanceObjectTargetType": ".catalog_allowance_object_target_type",
    "CatalogBulkErrorItem": ".catalog_bulk_error_item",
    "CatalogBulkResponse": ".catalog_bulk_response",
    "CatalogBulkResponseErrorsItem": ".catalog_bulk_response_errors_item",
    "CatalogBulkResponseSkippedItem": ".catalog_bulk_response_skipped_item",
    "CatalogBulkSkippedItem": ".catalog_bulk_skipped_item",
    "CatalogEntryBasicObject": ".catalog_entry_basic_object",
    "CatalogEntryBulkItem": ".catalog_entry_bulk_item",
    "CatalogEntryBulkItemAllowancesItem": ".catalog_entry_bulk_item_allowances_item",
    "CatalogEntryBulkItemAllowancesItemAllowanceType": ".catalog_entry_bulk_item_allowances_item_allowance_type",
    "CatalogEntryBulkItemPricesItem": ".catalog_entry_bulk_item_prices_item",
    "CatalogEntryBulkItemPricesItemPriceType": ".catalog_entry_bulk_item_prices_item_price_type",
    "CatalogEntryCreateRequest": ".catalog_entry_create_request",
    "CatalogEntryCreateRequestAllowancesItem": ".catalog_entry_create_request_allowances_item",
    "CatalogEntryCreateRequestAllowancesItemAllowanceType": ".catalog_entry_create_request_allowances_item_allowance_type",
    "CatalogEntryCreateRequestPricesItem": ".catalog_entry_create_request_prices_item",
    "CatalogEntryCreateRequestPricesItemPriceType": ".catalog_entry_create_request_prices_item_price_type",
    "CatalogEntryListResponse": ".catalog_entry_list_response",
    "CatalogEntryListResponseResultsItem": ".catalog_entry_list_response_results_item",
    "CatalogEntryObject": ".catalog_entry_object",
    "CatalogEntryObjectAllowancesItem": ".catalog_entry_object_allowances_item",
    "CatalogEntryObjectAllowancesItemAllowanceType": ".catalog_entry_object_allowances_item_allowance_type",
    "CatalogEntryObjectAllowancesItemTargetType": ".catalog_entry_object_allowances_item_target_type",
    "CatalogEntryObjectPricesItem": ".catalog_entry_object_prices_item",
    "CatalogEntryObjectPricesItemPriceTypeDisplay": ".catalog_entry_object_prices_item_price_type_display",
    "CatalogErrorResponse": ".catalog_error_response",
    "CatalogPriceCreateRequest": ".catalog_price_create_request",
    "CatalogPriceCreateRequestPriceType": ".catalog_price_create_request_price_type",
    "CatalogPriceItem": ".catalog_price_item",
    "CatalogPriceItemPriceTypeDisplay": ".catalog_price_item_price_type_display",
    "CompanyObject": ".company_object",
    "ErrorResponse": ".error_response",
    "InstantCaptureFileObject": ".instant_capture_file_object",
    "InvoiceCreationResponse": ".invoice_creation_response",
    "InvoiceCreationResponseBatch": ".invoice_creation_response_batch",
    "InvoiceCreationResponseBatchStatus": ".invoice_creation_response_batch_status",
    "InvoiceCreationResponseContainer": ".invoice_creation_response_container",
    "InvoiceCreationResponseInvoice": ".invoice_creation_response_invoice",
    "InvoiceCreationResponseInvoiceStatus": ".invoice_creation_response_invoice_status",
    "InvoiceCreationResponseProcessing": ".invoice_creation_response_processing",
    "InvoiceCreationResponseProcessingStatus": ".invoice_creation_response_processing_status",
    "InvoiceCreationResponseUpload": ".invoice_creation_response_upload",
    "InvoiceCreationResponseUploadUploadMethod": ".invoice_creation_response_upload_upload_method",
    "InvoiceDetailObject": ".invoice_detail_object",
    "InvoiceDetailObjectGlSplitsItem": ".invoice_detail_object_gl_splits_item",
    "InvoiceDetailObjectHistoryItem": ".invoice_detail_object_history_item",
    "InvoiceDetailObjectHistoryItemUser": ".invoice_detail_object_history_item_user",
    "InvoiceDetailObjectImagesItem": ".invoice_detail_object_images_item",
    "InvoiceDetailObjectItemsProcessingResult": ".invoice_detail_object_items_processing_result",
    "InvoiceDetailObjectItemsProcessingResultStatus": ".invoice_detail_object_items_processing_result_status",
    "InvoiceDetailObjectPaymentInfo": ".invoice_detail_object_payment_info",
    "InvoiceDetailObjectPaymentStatus": ".invoice_detail_object_payment_status",
    "InvoiceDetailObjectType": ".invoice_detail_object_type",
    "InvoiceItemVarianceListResponse": ".invoice_item_variance_list_response",
    "InvoiceItemVarianceListResponseResultsItem": ".invoice_item_variance_list_response_results_item",
    "InvoiceNeedsAttentionObject": ".invoice_needs_attention_object",
    "InvoiceNeedsAttentionObjectOnHold": ".invoice_needs_attention_object_on_hold",
    "InvoiceNeedsAttentionObjectPaymentStatus": ".invoice_needs_attention_object_payment_status",
    "InvoiceNeedsAttentionObjectType": ".invoice_needs_attention_object_type",
    "InvoiceObject": ".invoice_object",
    "InvoiceObjectImagesItem": ".invoice_object_images_item",
    "InvoiceObjectOnHold": ".invoice_object_on_hold",
    "InvoiceObjectPaymentStatus": ".invoice_object_payment_status",
    "InvoiceObjectType": ".invoice_object_type",
    "LineItemObject": ".line_item_object",
    "LocationObject": ".location_object",
    "OauthScope": ".oauth_scope",
    "PurchaseOrderCreateResponse": ".purchase_order_create_response",
    "PurchaseOrderCreateResponseItemsItem": ".purchase_order_create_response_items_item",
    "PurchaseOrderCreateResponseStatus": ".purchase_order_create_response_status",
    "PurchaseOrderDetail": ".purchase_order_detail",
    "PurchaseOrderDetailPurchaseOrder": ".purchase_order_detail_purchase_order",
    "PurchaseOrderDetailPurchaseOrderItemsItem": ".purchase_order_detail_purchase_order_items_item",
    "PurchaseOrderDetailPurchaseOrderStatus": ".purchase_order_detail_purchase_order_status",
    "PurchaseOrderSummary": ".purchase_order_summary",
    "PurchaseOrderSummaryStatus": ".purchase_order_summary_status",
    "PurchaseOrderUpdateResponse": ".purchase_order_update_response",
    "PurchaseOrderUpdateResponseStatus": ".purchase_order_update_response_status",
    "ReceiptBulkUpsertAsyncResponse": ".receipt_bulk_upsert_async_response",
    "ReceiptBulkUpsertAsyncResponseSummary": ".receipt_bulk_upsert_async_response_summary",
    "ReceiptCreateResponse": ".receipt_create_response",
    "ReceiptCreateResponseStatus": ".receipt_create_response_status",
    "ReceiptDetail": ".receipt_detail",
    "ReceiptDetailReceipt": ".receipt_detail_receipt",
    "ReceiptDetailReceiptItemsItem": ".receipt_detail_receipt_items_item",
    "ReceiptDetailReceiptStatus": ".receipt_detail_receipt_status",
    "ReceiptItem": ".receipt_item",
    "ReceiptSummary": ".receipt_summary",
    "ReceiptSummaryStatus": ".receipt_summary_status",
    "ReceiptUpdateResponse": ".receipt_update_response",
    "ReceiptUpdateResponseStatus": ".receipt_update_response_status",
    "VarianceListResponse": ".variance_list_response",
    "VarianceListResponseResultsItem": ".variance_list_response_results_item",
    "VarianceListResponseResultsItemLastInvoiceItem": ".variance_list_response_results_item_last_invoice_item",
    "VarianceObject": ".variance_object",
    "VarianceObjectInvoiceItems": ".variance_object_invoice_items",
    "VarianceObjectInvoiceItemsDataItem": ".variance_object_invoice_items_data_item",
    "VarianceObjectLastInvoiceItem": ".variance_object_last_invoice_item",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccountObject",
    "ApproverObject",
    "ApproverObjectApprover",
    "ApproverObjectPolicy",
    "BatchProgressResponse",
    "BatchProgressResponseStatus",
    "BatchResultsResponse",
    "BatchResultsResponseResultsItem",
    "BulkInvoiceFailure",
    "BulkInvoiceOperationResponse",
    "BulkInvoiceOperationResponseFailedItem",
    "BulkInvoiceUnexportOperationResponse",
    "BulkInvoiceUnexportOperationResponseFailedItem",
    "BulkInvoiceUnexportOperationResponseSkippedItem",
    "BulkUpsertAsyncResponse",
    "BulkUpsertAsyncResponseSummary",
    "CatalogAllowanceBulkItem",
    "CatalogAllowanceBulkItemAllowanceType",
    "CatalogAllowanceListResponse",
    "CatalogAllowanceListResponseResultsItem",
    "CatalogAllowanceListResponseResultsItemAllowanceType",
    "CatalogAllowanceListResponseResultsItemTargetType",
    "CatalogAllowanceNestedCreateRequest",
    "CatalogAllowanceNestedCreateRequestAllowanceType",
    "CatalogAllowanceNestedObject",
    "CatalogAllowanceNestedObjectAllowanceType",
    "CatalogAllowanceNestedObjectTargetType",
    "CatalogAllowanceObject",
    "CatalogAllowanceObjectAllowanceType",
    "CatalogAllowanceObjectTargetType",
    "CatalogBulkErrorItem",
    "CatalogBulkResponse",
    "CatalogBulkResponseErrorsItem",
    "CatalogBulkResponseSkippedItem",
    "CatalogBulkSkippedItem",
    "CatalogEntryBasicObject",
    "CatalogEntryBulkItem",
    "CatalogEntryBulkItemAllowancesItem",
    "CatalogEntryBulkItemAllowancesItemAllowanceType",
    "CatalogEntryBulkItemPricesItem",
    "CatalogEntryBulkItemPricesItemPriceType",
    "CatalogEntryCreateRequest",
    "CatalogEntryCreateRequestAllowancesItem",
    "CatalogEntryCreateRequestAllowancesItemAllowanceType",
    "CatalogEntryCreateRequestPricesItem",
    "CatalogEntryCreateRequestPricesItemPriceType",
    "CatalogEntryListResponse",
    "CatalogEntryListResponseResultsItem",
    "CatalogEntryObject",
    "CatalogEntryObjectAllowancesItem",
    "CatalogEntryObjectAllowancesItemAllowanceType",
    "CatalogEntryObjectAllowancesItemTargetType",
    "CatalogEntryObjectPricesItem",
    "CatalogEntryObjectPricesItemPriceTypeDisplay",
    "CatalogErrorResponse",
    "CatalogPriceCreateRequest",
    "CatalogPriceCreateRequestPriceType",
    "CatalogPriceItem",
    "CatalogPriceItemPriceTypeDisplay",
    "CompanyObject",
    "ErrorResponse",
    "InstantCaptureFileObject",
    "InvoiceCreationResponse",
    "InvoiceCreationResponseBatch",
    "InvoiceCreationResponseBatchStatus",
    "InvoiceCreationResponseContainer",
    "InvoiceCreationResponseInvoice",
    "InvoiceCreationResponseInvoiceStatus",
    "InvoiceCreationResponseProcessing",
    "InvoiceCreationResponseProcessingStatus",
    "InvoiceCreationResponseUpload",
    "InvoiceCreationResponseUploadUploadMethod",
    "InvoiceDetailObject",
    "InvoiceDetailObjectGlSplitsItem",
    "InvoiceDetailObjectHistoryItem",
    "InvoiceDetailObjectHistoryItemUser",
    "InvoiceDetailObjectImagesItem",
    "InvoiceDetailObjectItemsProcessingResult",
    "InvoiceDetailObjectItemsProcessingResultStatus",
    "InvoiceDetailObjectPaymentInfo",
    "InvoiceDetailObjectPaymentStatus",
    "InvoiceDetailObjectType",
    "InvoiceItemVarianceListResponse",
    "InvoiceItemVarianceListResponseResultsItem",
    "InvoiceNeedsAttentionObject",
    "InvoiceNeedsAttentionObjectOnHold",
    "InvoiceNeedsAttentionObjectPaymentStatus",
    "InvoiceNeedsAttentionObjectType",
    "InvoiceObject",
    "InvoiceObjectImagesItem",
    "InvoiceObjectOnHold",
    "InvoiceObjectPaymentStatus",
    "InvoiceObjectType",
    "LineItemObject",
    "LocationObject",
    "OauthScope",
    "PurchaseOrderCreateResponse",
    "PurchaseOrderCreateResponseItemsItem",
    "PurchaseOrderCreateResponseStatus",
    "PurchaseOrderDetail",
    "PurchaseOrderDetailPurchaseOrder",
    "PurchaseOrderDetailPurchaseOrderItemsItem",
    "PurchaseOrderDetailPurchaseOrderStatus",
    "PurchaseOrderSummary",
    "PurchaseOrderSummaryStatus",
    "PurchaseOrderUpdateResponse",
    "PurchaseOrderUpdateResponseStatus",
    "ReceiptBulkUpsertAsyncResponse",
    "ReceiptBulkUpsertAsyncResponseSummary",
    "ReceiptCreateResponse",
    "ReceiptCreateResponseStatus",
    "ReceiptDetail",
    "ReceiptDetailReceipt",
    "ReceiptDetailReceiptItemsItem",
    "ReceiptDetailReceiptStatus",
    "ReceiptItem",
    "ReceiptSummary",
    "ReceiptSummaryStatus",
    "ReceiptUpdateResponse",
    "ReceiptUpdateResponseStatus",
    "VarianceListResponse",
    "VarianceListResponseResultsItem",
    "VarianceListResponseResultsItemLastInvoiceItem",
    "VarianceObject",
    "VarianceObjectInvoiceItems",
    "VarianceObjectInvoiceItemsDataItem",
    "VarianceObjectLastInvoiceItem",
]
